@@ -1,10 +1,12 @@
 //  The Gaussian priors cases for basad
 //
 //  Created by Qingyan Xiang on 10/19/17.
-//  Copyright © 2017 Qingyan Xiang. All rights reserved.
+//  Updated on Nov 2021
+//  Copyright © 2021 Qingyan Xiang. All rights reserved.
 
 
 #include <math.h>
+#define STRICT_R_HEADERS
 #include <Rcpp.h>
 #include <RcppEigen.h>
 #include "utiliti.h"
