@@ -1,12 +1,14 @@
 //  The scale mixture priors cases for basad
 //
 //  Created by Qingyan Xiang on 10/19/17.
-//  Copyright © 2017 Qingyan Xiang. All rights reserved.
+//  Updated on Nov 2021
+//  Copyright © 2021 Qingyan Xiang. All rights reserved.
 
 #include <iostream>
 #include <stdio.h>
 #include <cstdlib>
 #include <math.h>
+#define STRICT_R_HEADERS
 #include <Rcpp.h>
 #include <RcppEigen.h>
 #include "utiliti.h"
